/*!
 * \file docmain.hpp
 * \brief This file contains documentation for Doxygen and does not have any significance with respect to C++.
 * \author Current Development: Stanford University.
 *         Original Structure: CADES 1.0 (2009).
 * \version 1.1.
 */

/*! 
 * \mainpage The SU$^2$ Suite
 * The Stanford University Unstructured (SU$^2$) suite is an open-source collection of C++ based software tools
 * to perform PDE analysis and PDE constrained optimization problems.  The toolset is designed with 
 * computational fluid dynamics and aerodynamic shape optimization in mind, but is extensible to
 * include other families of governing equations such as potential flow, electrodynamics, chemically reacting
 * flows, and many others.  SU$^2$ is under active development at 
 * <A HREF="http://www.stanford.edu/">Stanford University</A> in the
 * <A HREF="http://adl.stanford.edu/">Aerospace Design Lab (ADL)</A> of the 
 * <A HREF="http://aa.stanford.edu/">Department of Aeronautics and Astronautics</A> and is released under an
 * open-source license.
 * 
 * The following technical documentation describes the structure and details of the source code for developers. 
 * To read the more general documentation, including an introduction to the suite, user and developer guides and the latest 
 * releases for downloading, please click <A HREF="http://adl.stanford.edu/docs/display/SUSQUARED/SU2+Home">here</A>.
 *
 */

/*!
 * \defgroup Config Descriptions of Configuration Options.
 * \brief Group of variables that can be set using the configuration file.
 */

/*!
 * \defgroup ConvDiscr Discretization of the convective terms.
 * \brief Group of classes which define the numerical methods for 
 *		  discretizing the convective terms of a Partial Differential Equation. 
 *		  There are methods for solving the direct, adjoint and linearized 
 *		  systems of equations.
 */

/*!
 * \defgroup ViscDiscr Discretization of the viscous terms.
 * \brief Group of classes which define the numerical methods for 
 *		  discretizing the viscous terms of a Partial Differential Equation. 
 *		  There are methods for solving the direct, adjoint and linearized 
 *		  systems of equations.
 */

/*!
 * \defgroup SourceDiscr Discretization of the source terms.
 * \brief Group of classes which define the numerical methods for 
 *		  discretizing the source terms of a Partial Differential Equation. 
 *		  There are methods for solving the direct, adjoint and linearized 
 *		  systems of equations.
 */

/*!
 * \defgroup Potential_Flow_Equation Solving the potential flow equation.
 * \brief Group of classes which define the system of Potential flow equation in 
 *		  three formulations: direct, adjoint, and linearized.
 */

/*!
 * \defgroup Euler_Equations Solving the Euler's equations.
 * \brief Group of classes which define the system of Euler equations in 
 *		  three formulations: direct, adjoint, and linearized.
 */

/*!
 * \defgroup Navier_Stokes_Equations Solving the Navier-Stokes' equations.
 * \brief Group of classes which define the system of Navier-Stokes equations in 
 *		  three formulations: direct, adjoint, and linearized.
 */

/*!
 * \defgroup Turbulence_Model Solving the turbulence models.
 * \brief Group of classes which define the turbulence model in 
 *		  three formulations: direct, adjoint, and linearized.
 */
